# CBICQC

Essential quality control analysis of routine phantom stability MRI with single session and trend reporting

### Latest Version : 2021.7.8

### External Dependencies
FSL 6.0 or later (https://fsl.fmrib.ox.ac.uk/fsl/fslwiki/FslInstallation)

### PyPi installation
```pip3 install cbicqc```

### setuptools installation from source
```python setup.py install```
